==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/bg.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "Unknown user" : "Непознат потребител",
    "New comment …" : "Нов коментар...",
    "Delete comment" : "Изтрий коментар",
    "Post" : "Публикация",
    "Cancel" : "Отказ",
    "Edit comment" : "Редактирай коментра",
    "[Deleted user]" : "[Изтрит потребител]",
    "No comments yet, start the conversation!" : "Все-още няма коментари, започни разговор!",
    "More comments …" : "Още коментари...",
    "Save" : "Запазване",
    "Allowed characters {count} of {max}" : "Позволени символи {count} от {max}",
    "Error occurred while retrieving comment with id {id}" : "Възникна грешка по време на извличане на коментар с код {id}",
    "Error occurred while updating comment with id {id}" : "Възникна грешка по време на обновяване на коментар с код {id}",
    "Error occurred while posting comment" : "Възникна грешка по време на изпращане на коментар",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочетен коментар","%n непрочетени коментари"],
    "Comment" : "Коментар",
    "You commented" : "Вие коментирахте",
    "%1$s commented" : "%1$s коментира",
    "{author} commented" : "{author} коментира",
    "You commented on %1$s" : "Ти коментира за %1$s",
    "You commented on {file}" : "Ти коментира за {file}",
    "%1$s commented on %2$s" : "%1$s коментиран за %2$s",
    "{author} commented on {file}" : "{author} коментира за {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за файлове",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(Токущо) изтрит потребител те коментира в “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(Токущо) изтрит потребител те спомена в коментар за “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s те спомена в коментар за “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} те спомена в коментар за “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/bg.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментари",
    "Unknown user" : "Непознат потребител",
    "New comment …" : "Нов коментар...",
    "Delete comment" : "Изтрий коментар",
    "Post" : "Публикация",
    "Cancel" : "Отказ",
    "Edit comment" : "Редактирай коментра",
    "[Deleted user]" : "[Изтрит потребител]",
    "No comments yet, start the conversation!" : "Все-още няма коментари, започни разговор!",
    "More comments …" : "Още коментари...",
    "Save" : "Запазване",
    "Allowed characters {count} of {max}" : "Позволени символи {count} от {max}",
    "Error occurred while retrieving comment with id {id}" : "Възникна грешка по време на извличане на коментар с код {id}",
    "Error occurred while updating comment with id {id}" : "Възникна грешка по време на обновяване на коментар с код {id}",
    "Error occurred while posting comment" : "Възникна грешка по време на изпращане на коментар",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочетен коментар","%n непрочетени коментари"],
    "Comment" : "Коментар",
    "You commented" : "Вие коментирахте",
    "%1$s commented" : "%1$s коментира",
    "{author} commented" : "{author} коментира",
    "You commented on %1$s" : "Ти коментира за %1$s",
    "You commented on {file}" : "Ти коментира за {file}",
    "%1$s commented on %2$s" : "%1$s коментиран за %2$s",
    "{author} commented on {file}" : "{author} коментира за {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментари</strong> за файлове",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s те спомена в коментар за “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} те спомена в коментар за “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "(Токущо) изтрит потребител те коментира в “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "(Токущо) изтрит потребител те спомена в коментар за “{file}”"
},
"nplurals=2; plural=(n != 1);");
